﻿using Infragistics.Win.UltraWinExplorerBar;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Drawing.Imaging;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace WinExplorerBar_DifferentImageSizes
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            Image fullImage = Image.FromFile("32x32.png");
            Image smallImage = Image.FromFile("32x24.png");
            Image modifiedSmallImage = FixedSize(smallImage, 32, 32);
            UltraExplorerBarGroup group = new UltraExplorerBarGroup("Group1");
            group.Text = "Images";

            UltraExplorerBarItem item = new UltraExplorerBarItem("Item1");
            item.Text = "Full Image";
            item.Settings.AppearancesLarge.Appearance.Image = fullImage;
            group.Items.Add(item);

            item = new UltraExplorerBarItem("Item2");
            item.Text = "Small Image (stretched)";
            item.Settings.AppearancesLarge.Appearance.Image = smallImage;
            group.Items.Add(item);

            item = new UltraExplorerBarItem("Item3");
            item.Text = "Modified Small Image (with padding)";
            item.Settings.AppearancesLarge.Appearance.Image = modifiedSmallImage;
            group.Items.Add(item);

            ultraExplorerBar1.Groups.Add(group);
        }

        //  https://www.codeproject.com/Articles/2941/Resizing-a-Photographic-image-with-GDI-for-NET
        public Image FixedSize(Image imgPhoto, int Width, int Height)
        {
            int sourceWidth = imgPhoto.Width;
            int sourceHeight = imgPhoto.Height;
            int sourceX = 0;
            int sourceY = 0;
            int destX = 0;
            int destY = 0;

            float nPercent = 0;
            float nPercentW = 0;
            float nPercentH = 0;

            //  Calculate padding needed.
            nPercentW = ((float)Width / (float)sourceWidth);
            nPercentH = ((float)Height / (float)sourceHeight);
            if (nPercentH < nPercentW)
            {
                nPercent = nPercentH;
                destX = System.Convert.ToInt16((Width - (sourceWidth * nPercent)) / 2);
            }
            else
            {
                nPercent = nPercentW;
                destY = System.Convert.ToInt16((Height - (sourceHeight * nPercent)) / 2);
            }

            int destWidth = (int)(sourceWidth * nPercent);
            int destHeight = (int)(sourceHeight * nPercent);

            //  Here is our new image.
            Bitmap bmPhoto = new Bitmap(Width, Height, PixelFormat.Format32bppArgb);
            bmPhoto.SetResolution(imgPhoto.HorizontalResolution, imgPhoto.VerticalResolution);

            Graphics grPhoto = Graphics.FromImage(bmPhoto);
            grPhoto.Clear(Color.Transparent);
            grPhoto.InterpolationMode = InterpolationMode.HighQualityBicubic;

            grPhoto.DrawImage(imgPhoto, new Rectangle(destX, destY, destWidth, destHeight),
                              new Rectangle(sourceX, sourceY, sourceWidth, sourceHeight), GraphicsUnit.Pixel);

            grPhoto.Dispose();
            return bmPhoto;
        }
    }
}
